Density, distribution function, quantile function, and random generation for a Asymmetric Laplace Distribution.
dAsymLaplace(x, mu, sigma, tau, log)rAsymLaplace(n, mu, sigma, tau)
pAsymLaplace(q, mu, sigma, tau, lower.tail = 1, log.p = 0)
qAsymLaplace(p, mu, sigma, tau, lower.tail = 1, log.p = 0)
value to be computed.
location parameter.
scale parameter.
asymmetry parameter.
TRUE or 1 to return log probability. FALSE or 0 to return probability.
number of random draws. Currently only n = 1 is supported, but the argument exists for standardization of "r" functions.
quantile to be computed.
logical; if TRUE (default), probabilities are P[X <= x] otherwise, P[X > x].
probability to be computed.
Enrico Crema