Density and random generation of a logistic growth model distribution.
Usage
dLogisticGrowth(x, a, b, k, r, log)
rLogisticGrowth(n, a, b, k, r)
Value
For dLogisticGrowth: the probability (or likelihood) or log probability of an observed date x (in Cal BP). For rLogisticGrowth a simulated date in Cal BP.
Arguments
x
vector of calendar years (in BP).
a
lower (earliest) limit of the distribution (in BP).
b
upper (latest) limit of the distribution (in BP).
k
initial proportion of the carrying capacity (must be between 0 and 1).
r
intrinsic growth rate.
log
TRUE or 1 to return log probability. FALSE or 0 to return probability.
n
number of random draws. Currently only n = 1 is supported, but the argument exists for standardization of "r" functions.
Author
Enrico Crema
See Also
dLogisticGrowth2 for an alternative parametrisation.