Learn R Programming

nimbleCarbon (version 0.2.6)

dLogisticGrowth2: Logistic Growth Model (parametrisation with inflection point)

Description

Density and random generation of a logistic growth model distribution with alternative parametrisation.

Usage

dLogisticGrowth2(x, a, b, m, r, log)

rLogisticGrowth2(n, a, b, m, r)

Value

For dLogisticGrowth2: the probability (or likelihood) or log probability of an observed date x (in Cal BP). For rLogisticGrowth2 a simulated date in Cal BP.

Arguments

x

vector of calendar years (in BP).

a

lower (earliest) limit of the distribution (in BP).

b

upper (latest) limit of the distribution (in BP).

m

inflection point in BP (i.e. point with the highest growth rate).

r

intrinsic growth rate.

log

TRUE or 1 to return log probability. FALSE or 0 to return probability.

n

number of random draws. Currently only n = 1 is supported, but the argument exists for standardization of "r" functions.

Author

Enrico Crema

Details

This is an alternative parametrisation of dLogisiticGrowth, where m is equal to log(-(k-1)/k)/r.

Examples

Run this code
p = list(m=4500,r=0.007)
modelPlot(model = dLogisticGrowth2,a=6000,b=4000,params=p,alpha = 1)

Run the code above in your browser using DataLab